.. Stuweparser documentation master file, created by
   sphinx-quickstart on Sun Oct 29 23:44:32 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Stuweparser
===========

.. image:: https://travis-ci.org/Trybnetic/stuweparser.svg?branch=master
    :target: https://travis-ci.org/Trybnetic/stuweparser?branch=master

.. image:: https://landscape.io/github/Trybnetic/stuweparser/master/landscape.svg?style=flat
   :target: https://landscape.io/github/Trybnetic/stuweparser/master

.. image:: https://coveralls.io/repos/github/Trybnetic/stuweparser/badge.svg?branch=master
    :target: https://coveralls.io/github/Trybnetic/stuweparser?branch=master

.. image:: https://img.shields.io/github/license/trybnetic/stuweparser.svg
    :target: https://github.com/trybnetic/stuweparser/blob/master/LICENSE.txt

Stuweparser is a python3 package which contains a collection of functions
to crawl and parse the website of the `Studierendenwerk Tübingen-Hohenheim
<https://www.my-stuwe.de/>`_.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   installation
   refernce
   examples
   about
